////////////////////////////////////////////////////////////////////////////////
//	Attachment.cpp:	Implements the Jet Attachments object class
//
//	This class defines a single attachment for a given indexed mesh resource file.
//	All the attachments are contained within the CAttachments class
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "Attachment.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

////////////////////////////////////////////////////////////////////////////////
// Construction/Destruction
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//	Default constructor
//
CAttachment::CAttachment()
{

}

////////////////////////////////////////////////////////////////////////////////
//	Standard destructor
//
CAttachment::~CAttachment()
{

}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the full size of this Attachment object in the final .IM file
//
//   COMMENTS:
//
//	This method will add up the total lengths of all its internal components,
//	and return the total lengths.
//
//    RETURN VALUES:
//		The full size of this object in the .IM file
//
DWORD CAttachment::GetFullSize()
{
	DWORD	dwTotalSize	= 0;

	dwTotalSize += sizeof (DWORD);			// name length
	dwTotalSize += GetNameSize (m_szName);	// name size
	dwTotalSize += sizeof (m_theValues);	// rest of the value sizes

	return dwTotalSize;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the reamining size of this Attachment3 object after its chunk size
//
//   COMMENTS:
//
//	This object has no length field within a standard header, so it will simply
//	return the full length for the remaining length
//
//    RETURN VALUES:
//		The remaining size of this object after the chunk size
//
DWORD CAttachment::GetRemainingSize()
{
	return GetFullSize();
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Write this object and its contents to the output file
//
//   COMMENTS:
//
//	This method will write the contents of the material object, which includes
//	textures, to the output *.IM Indexed Mesh file.
//
//	  hOutputFile		The handle of the output file to use
//
//    RETURN VALUES:
//		true:	If no errors occur
//		false:	Otherwise
//
bool CAttachment::WriteToOutputFile(HANDLE	hOutputFile)
{
	char		szName [512];

	strcpy (szName, m_szName);
	strcat (szName, "    ");
//
//			Write out the name size
//
	m_dwNameLength = GetNameSize (m_szName);
	if (! PerformTheWrite(hOutputFile, &m_dwNameLength, sizeof (m_dwNameLength), 
						  "Write of MATL Header failed"))
	{
		return false;
	}
//
//			Write out the name padded to the next DWORD boundary
//
	if (! PerformTheWrite(hOutputFile, &szName, GetNameSize (m_szName), 
						  "Write of attachment name failed"))
	{
		return false;
	}
//
//			Write out the remaining data values
//
	if (! PerformTheWrite(hOutputFile, &m_theValues, sizeof (m_theValues), 
						  "Write of MATL After Header failed"))
	{
		return false;
	}
	return true;
}

////////////////////////////////////////////////////////////////////////////////
