////////////////////////////////////////////////////////////////////////////////
//	Attachment.h:	The Jet Attachments object class
//
//	This class defines a single attachment for a given indexed mesh resource file.
//	All the attachments are contained within the CAttachments class
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_ATTACHMENT_H__INCLUDED_)
#define AFX_ATTACHMENT_H__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "BaseIMObject.h"

class CAttachment : public CBaseIMObject  
{
public:

			CAttachment		();
	virtual ~CAttachment	();

	DWORD	GetFullSize			();
	DWORD	GetRemainingSize	();
	bool	WriteToOutputFile	(HANDLE	hOutputFile);

	inline void SetName			(char *	szName)
	{
		strcpy (m_szName, szName);
	}

	inline void SetPosition		(float	x,
								 float	y,
								 float	z)
	{
		m_theValues.afPosition [0] = x;
		m_theValues.afPosition [1] = y;
		m_theValues.afPosition [2] = z;
	}

	inline void SetOrientation	(float	x00,
								 float	x01,
								 float	x02,
								 float	x10,
								 float	x11,
								 float	x12,
								 float	x20,
								 float	x21,
								 float	x22)
	{
		m_theValues.afOrientation [0][0] = x00;
		m_theValues.afOrientation [0][1] = x01;
		m_theValues.afOrientation [0][2] = x02;
		m_theValues.afOrientation [1][0] = x10;
		m_theValues.afOrientation [1][1] = x11;
		m_theValues.afOrientation [1][2] = x12;
		m_theValues.afOrientation [2][0] = x20;
		m_theValues.afOrientation [2][1] = x21;
		m_theValues.afOrientation [2][2] = x22;
	}

protected:

	typedef struct AttachmentValues
	{
		float	afOrientation [3][3];
		float	afPosition[3];
	};

	AttachmentValues		m_theValues;	// the attachment values

	DWORD		m_dwNameLength;				// length of the name
	char		m_szName [1024];			// attachment name

};

#endif // !defined(AFX_ATTACHMENT_H__INCLUDED_)
////////////////////////////////////////////////////////////////////////////////
