////////////////////////////////////////////////////////////////////////////////
//	Attachments.h:	The Jet Attachments object class
//
//	This class defines the Attachment container class that holds all the attachments
//	for an Indexed Mesh resource file.  This is an optional chunk
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_ATTACHMENTS_H__INCLUDED_)
#define AFX_ATTACHMENTS_H__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "BaseIMObject.h"
#include "Attachment.h"
#include <vector>

typedef std::vector<CAttachment *> ATTACHMENTVECTOR;

class CAttachments : public CBaseIMObject  
{
public:
			CAttachments		();
	virtual ~CAttachments		();

	DWORD	GetFullSize			();
	DWORD	GetRemainingSize	();
	bool	WriteToOutputFile	(HANDLE			hOutputFile);
	bool	CreateNewAttachment	(CAttachment*&	pCurrentAttachment);

	DWORD	GetAttachmentCount	()
	{
		return m_theHeader.dwAttachmentCount;
	}

protected:

	typedef struct Header
	{
		char	chATCHChunkID [4];
		DWORD	dwChunkSize;
		DWORD	dwVersion;
		DWORD	dwAttachmentCount;
	};

	Header	m_theHeader;				// the Attachments chunk's header data
	ATTACHMENTVECTOR	m_vAttachments;	// STL Vector of attachments
};

#endif // !defined(AFX_ATTACHMENTS_H__INCLUDED_)
////////////////////////////////////////////////////////////////////////////////
