////////////////////////////////////////////////////////////////////////////////
//	BaseDataSource.cpp:	Implementation of the base class for 3D model data gathering
//
//	This is the base class for all data-gathering functions to extract 3D model
//	information from modeling applications.  Some implimentations may be through
//	application plug-ins while other read simple export text files.  This base
//	class contains attributes and methods common to all data source classes.
//
//	The data source is the most changable part of this application.  Plug-ins wil
//	be part of a component that runs within the modeling application.  Classes
//	that read exported files may run as stand-alone applications.  The choice of
//	the data source class used controls the overall form of the application.
//
//	This base class includes the base file convertion routines that do that actual
//	work of converting the data to the form the Jet engine requires.  The conversion
//	routines will not change from one modeling application to another, and provide
//	a standard interface for the data source classes to use to build and write out
//	Auran Jet resource files.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "BaseDataSource.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

////////////////////////////////////////////////////////////////////////////////
// Construction/Destruction
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//	Default constructor
//
CBaseDataSource::CBaseDataSource()
{
	JetFormatter = new CBaseResourceFormatter ();
	JetFormatter->AssertValid();
}

////////////////////////////////////////////////////////////////////////////////
//	Standard destructor
//
CBaseDataSource::~CBaseDataSource()
{
	delete JetFormatter;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Clean up the allocated memory
//
//   COMMENTS:
//
//	Override this method to clean up the allocated memory for your specific
//	data source class.  Call this base version to call the Cleanup() routine of
//	the CBaseResourceFormatter class to clean it up also
//
//    RETURN VALUES:
//		true:	If no errors occur
//		false:	Otherwise
//
bool CBaseDataSource::Cleanup()
{
	JetFormatter->Cleanup();
	return true;
}

////////////////////////////////////////////////////////////////////////////////
