////////////////////////////////////////////////////////////////////////////////
//	BaseDataSource.h:	The base class for 3D model data gathering
//
//	This is the base class for all data-gathering functions to extract 3D model
//	information from modeling applications.  Some implimentations may be through
//	application plug-ins while other read simple export text files.  This base
//	class contains attributes and methods common to all data source classes.
//
//	The data source is the most changable part of this application.  Plug-ins will
//	be part of a component that runs within the modeling application.  Classes
//	that read exported files may run as stand-alone applications.  The choice of
//	the data source class used controls the overall form of the application.
//
//	This base class includes the base file convertion routines that do that actual
//	work of converting the data to the form the Jet engine requires.  The conversion
//	routines will not change from one modeling application to another, and provide
//	a standard interface for the data source classes to use to build and write out
//	Auran Jet resource files.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#include "BaseResourceFormatter.h"

#if !defined(AFX_BASEDATASOURCE_H__INCLUDED_)
#define AFX_BASEDATASOURCE_H__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

class CBaseDataSource : public CObject  
{
public:
			CBaseDataSource		();
	virtual	~CBaseDataSource	();

	virtual bool	Cleanup		();

protected:

	CBaseResourceFormatter * JetFormatter;

};

#endif // !defined(AFX_BASEDATASOURCE_H__INCLUDED_)

////////////////////////////////////////////////////////////////////////////////
