////////////////////////////////////////////////////////////////////////////////
//	BaseIMObject.cpp:	The base class for IM object classes
//
//	This is the base class for all Jet *.IM object classes.  It includes
//	virtual methods to return the full size and the remaining size (after any
//	initial ID and length fields) of the entire class (including the full sizes
//	of all contained objects).  It also contains the write procedures used by all
//	Jet object classes to write their output to the final converted *.IM output file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "BaseIMObject.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

////////////////////////////////////////////////////////////////////////////////
// Construction/Destruction
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//	Default constructor
//
CBaseIMObject::CBaseIMObject()
{
}

////////////////////////////////////////////////////////////////////////////////
//	Standard destructor
//
//	Note:  We are not making another copy of the texture objects in the m_vTexture
//	vector, so we should not delete these objects in this destructor.
//
CBaseIMObject::~CBaseIMObject()
{
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the full size of this object in the final .IM file
//
//   COMMENTS:
//
//	This method will add up the total lengths of all its internal components,
//	and return the total lengths.
//
//    RETURN VALUES:
//		The full size of this object in the .IM file
//
DWORD CBaseIMObject::GetFullSize()
{
	return 0;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the size of this object remaining after the size value
//
//   COMMENTS:
//
//	This method will return the size of this object less the size occupied by
//	the heading ID and the size field itself.
//
//    RETURN VALUES:
//		The remaining size of this object.
//
DWORD CBaseIMObject::GetRemainingSize()
{
	return 0;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Write this object and its contents to the output file
//
//   COMMENTS:
//
//	This virtual method will write the contents of this object to the output
//	resource file.  Override this function for each actual resource class
//
//	  hOutputFile		Handle to the output file to use.
//
//    RETURN VALUES:
//		true:	If no errors occur
//		false:	Otherwise
//
bool CBaseIMObject::WriteToOutputFile(HANDLE hOutputFile)
{
	return true;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the size of an object or file name expanded to a DWORD boundary
//
//   COMMENTS:
//
//	This method will return the length of the  name expanded to a DWORD 
//	boundary as required by the .IM file specifications.
//
//	  strName			The name to size.
//
//    RETURN VALUES:
//		The full size of the name area
//
DWORD CBaseIMObject::GetNameSize (CString	strName)
{
	DWORD dwFileNameSize = strName.GetLength();

	 return dwFileNameSize += (4 - (dwFileNameSize % 4));
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the size of an object or file name expanded to a DWORD boundary
//
//   COMMENTS:
//
//	This method will return the length of the  name expanded to a DWORD 
//	boundary as required by the .IM file specifications.
//
//	  strName			The name to size.
//
//    RETURN VALUES:
//		The full size of the name area
//
DWORD CBaseIMObject::GetNameSize (char * strName)
{
	DWORD dwFileNameSize = strlen(strName);

	 return dwFileNameSize += (4 - (dwFileNameSize % 4));
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Write information to the output file
//
//   COMMENTS:
//
//	This method will perform the actual write to the output file and will check
//	for any resulting errors.  If errors occur, it will report them using the
//	passed message, and return a false value.  Otherwise it will return a true
//	value
//
//	  hOutputFile		The handle of the output file to use
//	  pData				Pointer to the data to write out to the file
//	  dwSize			The size in bytes of the data to write
//	  szErrorMsg		The error message to display if the write fails.
//
//    RETURN VALUES:
//		true	If no errors occur
//		False	Otherwise
//
bool CBaseIMObject::PerformTheWrite(HANDLE	hOutputFile,
								    void *	pData,
								    DWORD	dwSize,
									char *	szErrorMsg)
{
	DWORD dwBytesWritten;

	WriteFile (hOutputFile, pData, dwSize, &dwBytesWritten, NULL);
	if (dwBytesWritten != dwSize)
	{
		MessageBox (NULL, szErrorMsg, NULL, MB_OK );
		return false;
	}
	return true;
}

////////////////////////////////////////////////////////////////////////////////
