////////////////////////////////////////////////////////////////////////////////
//	BaseResourceFormatter.h:	The base class for Jet resource file formatting
//
//	This is the base class containing all of the resource formatting classes
//	needed to create Jet resource input files.  As of this writing, only the
//	*.IM file formatting routines exist.  Some additional work will be needed
//	to implement the other Jet resource file formats.
//
//	This base class contains all the IMObject classes used to represent headers,
//	chunks, or other data elements of the *.IM file.  It controls their creation
//	provides methots to fill them with data, and the executes the utlimate task
//	of writing their data to the final output file.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_BASERESOURCEFORMATTER_H__INCLUDED_)
#define AFX_BASERESOURCEFORMATTER_H__INCLUDED_

#include "IMHeader.h"
#include "KINHeader.h"
#include "Mesh.h"
#include <vector>

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000


class CBaseResourceFormatter : public CObject  
{
public:
			CBaseResourceFormatter	();
	virtual ~CBaseResourceFormatter	();

	void	SetIMOutputFileHandle	(HANDLE		hOutputFile);
	void	SetKINOutputFileHandle	(HANDLE		hOutputFile);
	bool	CreateNewMesh			(CMesh*&	pCurrentMesh);
	void	SetModelPosition		(float X, 
									 float Y, 
									 float Z);
	bool	GetMesh					(CMesh*&	pCurrentMesh,
									 char *		szMeshName);
	bool	WriteOutTheIMFile		();
	bool	WriteOutTheKINFile		();
	bool	Cleanup					();

	inline void	GetInfoHeaderChunk	(CInfoHeader*& pCInfoHeader)
	{
		pCInfoHeader = &m_InfoHeader;
	}

	inline void	GetInfluenceChunk	(CInfluence*& pInfluence)
	{
		pInfluence = &m_Influence;
	}

	inline void	GetAttachmentsChunk	(CAttachments*& pAttachments)
	{
		pAttachments = &m_Attachments;
	}

	inline void	GetKINInfoHeaderChunk	(CKINInfoHeader*&	pKINInfoHeader)
	{
		m_pKINHeader->GetKINInfoHeaderChunk (pKINInfoHeader);
	}

	bool CreateNewEventDetail			(CEventDetail*&		pCurrentEventDetail)
	{
		return m_pKINHeader->CreateNewEventDetail (pCurrentEventDetail);
	}

	bool CreateRootBone					(CSkeletonBone*&	pRootBone)
	{
		return m_pKINHeader->CreateRootBone (pRootBone);
	}

	bool CreateNewFrame					(CFrame*&			pCurrentFrame)
	{
		return m_pKINHeader->CreateNewFrame (pCurrentFrame);
	}


protected:


	MESHVECTOR		m_vMesh;						// Vector of available meshes

	CIMHeader		m_IMHeader;						// The IM Header object
	CKINHeader *	m_pKINHeader;					// The KIN Header object
	CInfoHeader		m_InfoHeader;					// The INFO Header object
	CInfluence		m_Influence;					// The INFL chunk object
	CAttachments	m_Attachments;					// the ATCH chunk object
	HANDLE			m_hOutputFile;					// Handle to the output file
	HANDLE			m_hIMOutputFile;				// Handle to the output file
	HANDLE			m_hKINOutputFile;				// Handle to the output file

};

#endif // !defined(AFX_BASERESOURCEFORMATTER_H__INCLUDED_)

////////////////////////////////////////////////////////////////////////////////
