////////////////////////////////////////////////////////////////////////////////
//	Bone.h:	The Jet bone object class
//
//	This class defines individual bones within the influence chuck.  It is not
//	itself a complete chunk, but occurs zero to multiple times within each
//	normal Influence chunk.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_BONE_H__INCLUDED_)
#define AFX_BONE_H__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "BaseIMObject.h"
#include "BoneInfluenceChunk.h"
#include <vector>

typedef std::vector<CBoneInfluenceChunk *> BONEINFLUENCEVECTOR;

class CBone : public CBaseIMObject  
{
public:
			CBone				();
	virtual ~CBone				();

	DWORD	GetFullSize			();
	DWORD	GetRemainingSize	();
	bool	WriteToOutputFile	(HANDLE					hOutputFile);
	bool	CreateNewInfluence	(CBoneInfluenceChunk*&	pCurrentInfluence);

	inline void SetBoneName			(char * strBoneName)
	{
		strcpy (m_strBoneName, strBoneName);
		m_dwBoneNameSize = GetNameSize (m_strBoneName);
	}

	inline void SetParentName		(char * strParentName)
	{
		strcpy (m_strParentName, strParentName);
		m_dwParentNameSize = GetNameSize(m_strParentName);
	}

	inline void SetLocalPosition	(float	x,
									 float	y,
									 float	z)
	{
		m_theValues.afLocalPosition [0] = x;
		m_theValues.afLocalPosition [1] = y;
		m_theValues.afLocalPosition [2] = z;
	}

	inline void SetLocalOrientation	(float	x00,
									 float	x01,
									 float	x02,
									 float	x10,
									 float	x11,
									 float	x12,
									 float	x20,
									 float	x21,
									 float	x22)
	{
		m_theValues.mfLocalOrientation [0][0] = x00;
		m_theValues.mfLocalOrientation [0][1] = x01;
		m_theValues.mfLocalOrientation [0][2] = x02;
		m_theValues.mfLocalOrientation [1][0] = x10;
		m_theValues.mfLocalOrientation [1][1] = x11;
		m_theValues.mfLocalOrientation [1][2] = x12;
		m_theValues.mfLocalOrientation [2][0] = x20;
		m_theValues.mfLocalOrientation [2][1] = x21;
		m_theValues.mfLocalOrientation [2][2] = x22;
	}

protected:

	DWORD	m_dwBoneNameSize;				// the length of the bone's nme
	DWORD	m_dwParentNameSize;				// the length of the parent bone's name
	char 	m_strBoneName  [1024];			// the bone's name
	char	m_strParentName[1024];			// the bone's Parent's name

	typedef struct Bone_Values
	{
		float	afLocalPosition	[3];		// the X, Y, Z coordinates for this bone
		float	mfLocalOrientation[3][3];	// Matrix for the local orientation
		DWORD	dwCount;					// bone influence count
	};
	Bone_Values		m_theValues;			// the mesh header values

	BONEINFLUENCEVECTOR		m_vBoneInfluence;	// STL Vector of bone influences
};

#endif // !defined(AFX_BONE_H__INCLUDED_)
