////////////////////////////////////////////////////////////////////////////////
//	BoneInfluenceChunk.cpp:	Implementation of the Jet Influence Vertex object class
//
//	This class defines a single Bone Influence Chuck which contains the vertices
//	influenced by a single bone.
//	within a CBone object.  It contains a few simple values along with methods
//	to set and write out those values.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "BoneInfluenceChunk.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

////////////////////////////////////////////////////////////////////////////////
// Construction/Destruction
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//	Default constructor
//
CBoneInfluenceChunk::CBoneInfluenceChunk()
{

}

////////////////////////////////////////////////////////////////////////////////
//	Standard destructor
//
CBoneInfluenceChunk::~CBoneInfluenceChunk()
{
//
//			Clean up the vertex objects pointed to by m_vVertices
//
	BONEVERTEXVECTOR::iterator pVertex = m_vVertices.begin ();
	while (pVertex != m_vVertices.end ())
	{
		delete (CInfluenceVertex *) (*pVertex);
		pVertex++;
	}
	m_vVertices.clear();
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the full size of this object in the final .IM file
//
//   COMMENTS:
//
//	This method will add up the total lengths of all its internal components,
//	and return the total lengths.
//
//    RETURN VALUES:
//		The full size of this object in the .IM file
//
DWORD CBoneInfluenceChunk::GetFullSize ()
{
	DWORD	dwTotalSize		= 0;
//
//			Start with the attribute values
//
	dwTotalSize += sizeof (m_theValues);			// header size
//
//			Add in the size of all the contained vertex objects
//			and return the total size
//
	dwTotalSize += (m_vVertices.size() * m_exampleVertex.GetFullSize());
	return dwTotalSize;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the reamining size of this  object after its chunk size
//
//   COMMENTS:
//
//	This object has no length field within a standard header, so it will simply
//	return the full length for the remaining length
//
//    RETURN VALUES:
//		The remaining size of this object
//
DWORD CBoneInfluenceChunk::GetRemainingSize ()
{
	return GetFullSize ();
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Write this object and its contents to the output file
//
//   COMMENTS:
//
//	This method will write the contents of the influence vertes object to the
//	output *.IM Indexed Mesh file.
//
//	  hOutputFile		The handle of the output file to use
//
//    RETURN VALUES:
//		true:	If no errors occur
//		false:	Otherwise
//
bool CBoneInfluenceChunk::WriteToOutputFile (HANDLE	hOutputFile)
{
//
//			Make sure the vertex count is set, and then
//			Write out the object
//
	m_theValues.dwVertexCount = m_vVertices.size();
	if (! PerformTheWrite(hOutputFile, &m_theValues, sizeof (m_theValues), 
						  "Write of Influence Vertex values failed"))
	{
		return false;
	}
//
//			Write out each vertex
//
	CInfluenceVertex * ptrVertex;
	BONEVERTEXVECTOR::iterator pVertex = m_vVertices.begin ();
	while (pVertex != m_vVertices.end ())
	{
		ptrVertex = (*pVertex);
		ptrVertex->WriteToOutputFile (hOutputFile);
		pVertex++;
	}

	return true;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Create a new CInfluenceVertex object and put it into the vertex vector
//
//   COMMENTS:
//
//	This method will create a new CInfluenceVertex object and put it into the vertex vector.
//	It will then return a pointer to that CInfluenceVertex object so the calling routine can
//	do whatever it wants with it.
//
//	  pCurrentVertex	Returned pointer to the new CInfluenceVertex object just created
//
//    RETURN VALUES:
//		true	If no errors occur
//		False	Otherwise
//
bool CBoneInfluenceChunk::CreateNewVertex(CInfluenceVertex*& pCurrentVertex)
{
//			Create the vertex, insure that it is valid, and put it into the 
//			vertex vector
//
	pCurrentVertex = new CInfluenceVertex ();
	pCurrentVertex->AssertValid();
	m_vVertices.push_back (pCurrentVertex);
	return true;
}


////////////////////////////////////////////////////////////////////////////////
