////////////////////////////////////////////////////////////////////////////////
//	BoneInfluenceChunk.h:	The Jet Influence Vertex object class
//
//	This class defines a single Bone Influence Chuck which contains the vertices
//	influenced by a single bone.
//	within a CBone object.  It contains a few simple values along with methods
//	to set and write out those values.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_BONEINFLUENCECHUNK_H__INCLUDED_)
#define AFX_BONEINFLUENCECHUNK_H__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "InfluenceVertex.h"
#include <vector>

typedef std::vector<CInfluenceVertex *> BONEVERTEXVECTOR;

class CBoneInfluenceChunk : public CBaseIMObject  
{
public:
			CBoneInfluenceChunk		();
	virtual ~CBoneInfluenceChunk	();

	DWORD	GetFullSize				();
	DWORD	GetRemainingSize		();
	bool	WriteToOutputFile		(HANDLE				hOutputFile);
	bool	CreateNewVertex			(CInfluenceVertex*&	pCurrentVertex);

	inline void	SetIndex			(DWORD				dwIndex)
	{
		m_theValues.dwIndex = dwIndex;
	}

protected:

	BONEVERTEXVECTOR	m_vVertices;	// STL Vector of bone influence vertices
	CInfluenceVertex	m_exampleVertex;// vertex object used for sizing

	typedef struct Vertex_Values
	{
		DWORD	dwIndex;
		DWORD	dwVertexCount;
	};
	Vertex_Values		m_theValues;		// the mesh header values

};

#endif // !defined(AFX_BONEINFLUENCECHUNK_H__INCLUDED_)
////////////////////////////////////////////////////////////////////////////////
