////////////////////////////////////////////////////////////////////////////////
//	Event.cpp:	Implements the Jet Event class
//
//	This class defines the events that occur within an animation (kin) file.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "Event.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

////////////////////////////////////////////////////////////////////////////////
// Construction/Destruction
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//	Default constructor
//
CEvent::CEvent()
{
	strncpy (&m_theHeader.chChunkID[0], "EVNT", 4);
	m_theHeader.dwChunkSize		= 0;
	m_theHeader.dwVersion		= 100;
	m_theHeader.dwEventCount	= 0;
}

////////////////////////////////////////////////////////////////////////////////
//	Standard destructor
//
CEvent::~CEvent()
{
//
//			Clean up the event detail objects pointed to by m_pvEvents
//
	EVENTVECTOR::iterator pEventDetails = m_pvEvents->begin ();
	while (pEventDetails != m_pvEvents->end ())
	{
		delete (CEventDetail *) (*pEventDetails);
		pEventDetails++;
	}
	m_pvEvents->clear();
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the full size of this CEvent object in the final .KIN file
//
//   COMMENTS:
//
//	This method will return the length of the full CEvent heading..
//
//    RETURN VALUES:
//		The full size of this object in the .KIN file
//
DWORD CEvent::GetFullSize()
{
	CEventDetail *	ptrEvent;
	DWORD			dwTotalSize	= sizeof (m_theHeader);	// start with the header size
//
//			Count the event detail objects we will use, and sum their total size.
//
	m_theHeader.dwEventCount = 0;
	EVENTVECTOR::iterator pEvent = m_pvEvents->begin ();
	while (pEvent != m_pvEvents->end ())
	{
		ptrEvent = (*pEvent);
		dwTotalSize += ptrEvent->GetFullSize ();
		m_theHeader.dwEventCount++;
		pEvent++;
	}

	return dwTotalSize;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the reamining size of this INFO object after its chunk size
//
//   COMMENTS:
//
//	This method will get the total length of this object in the .KIN file, and
//	will subtract the leading "EVNT" text and chunk size DWORD to return the
//	remaining size of the object.
//
//    RETURN VALUES:
//		The remaining size of this object after the chunk size
//
DWORD CEvent::GetRemainingSize()
{
	m_theHeader.dwChunkSize = GetFullSize () - (4 + sizeof (DWORD));
	return m_theHeader.dwChunkSize;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Write this header and its contents to the output file
//
//   COMMENTS:
//
//	This method will write the contents of the INFO Header, which happens to be
//	the whole file, to the output *.KIN Animation file.
//
//	  hOutputFile		The handle of the output file to use
//
//    RETURN VALUES:
//		true:	If no errors occur
//		false:	Otherwise
//
bool CEvent::WriteToOutputFile(HANDLE			hOutputFile)
{
	CEventDetail *	ptrEvent;
//
//			Write out the CEvent header
//
	m_theHeader.dwEventCount = m_pvEvents->size ();
	GetRemainingSize();
	if (! PerformTheWrite(hOutputFile, &m_theHeader, sizeof (m_theHeader), 
						  "Write of CEvent Header failed"))
	{
		return false;
	}
//
//			Write out each CEvent object
//
	EVENTVECTOR::iterator pEvent = m_pvEvents->begin ();
	while (pEvent != m_pvEvents->end ())
	{
		ptrEvent = (*pEvent);
		ptrEvent->WriteToOutputFile (hOutputFile);
		pEvent++;
	}

	return true;
}
