////////////////////////////////////////////////////////////////////////////////
//	EventDetail.cpp:	Implements the Jet EventDetail class
//
//	This class defines the details of the individual events that occur within an
//	animation (kin) file.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "EventDetail.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

////////////////////////////////////////////////////////////////////////////////
// Construction/Destruction
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//	Default constructor
//
CEventDetail::CEventDetail()
{
	m_szName[0] = '\0';
}

////////////////////////////////////////////////////////////////////////////////
//	Standard destructor
//
CEventDetail::~CEventDetail()
{
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the full size of this INFO object in the final .IM file
//
//   COMMENTS:
//
//	This method will return the length of the full EventDetail data.
//
//    RETURN VALUES:
//		The full size of this object in the .IM file
//
DWORD CEventDetail::GetFullSize()
{
	DWORD	dwTotalSize	= 0;

	m_theData.dwNameSize = GetNameSize (m_szName);
	dwTotalSize = sizeof (m_theData) +		// header type
				  GetNameSize (m_szName);	// EventDetail image file name size

	return dwTotalSize;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the reamining size of this object
//
//   COMMENTS:
//
//	There is no separte header for this class, so the remaining size will be the
//	same as the full size.
//
//    RETURN VALUES:
//		The remaining size of this object after the chunk size
//
DWORD CEventDetail::GetRemainingSize()
{
	return GetFullSize ();
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Write this object to the output file
//
//   COMMENTS:
//
//	This method will write the contents of the CEventDetail object to the 
//	output *.IM Indexed Mesh file.
//
//	  hOutputFile		The handle of the output file to use
//
//    RETURN VALUES:
//		true:	If no errors occur
//		false:	Otherwise
//
bool CEventDetail::WriteToOutputFile(HANDLE			hOutputFile)
{
	char	szOutputName [MAX_PATH + 5];
//
//			Load the output variables with the proper values
//
	m_theData.dwNameSize = GetNameSize (m_szName);
	_strnset (szOutputName, 0, GetNameSize (m_szName));
	strcpy   (szOutputName, m_szName);
//
//			Write out the data structure
//
	if (! PerformTheWrite(hOutputFile, &m_theData, sizeof (m_theData), 
						  "Write of INFO Header failed"))
	{
		return false;
	}
//
//			Write out the name padded to the next DWORD boundary
//
	if (! PerformTheWrite(hOutputFile, &szOutputName, GetNameSize (m_szName), 
						  "Write of TEXTURE image name failed"))
	{
		return false;
	}

	return true;
}
