////////////////////////////////////////////////////////////////////////////////
//	Face.h:	The Jet Face object class
//
//	This class defines the Face object used to describe an individual
//	triangle in a mesh.  It contains indices into the vertex array to indicate the
//	three defining vertices, a normal vector, and other values that define each
//	individual face.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_FACE_H_INCLUDED_)
#define AFX_FACE_H_INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "BaseIMObject.h"
#include "Vertex.h"
#include <math.h>

class CFace : public CBaseIMObject  
{
public:
			CFace();
	virtual ~CFace();

	bool	CalculateNormal			(CVertex *	pV1,
									 CVertex *	pV2,
									 CVertex *	pV3);
	bool	WriteVertsToOutputFile	(HANDLE		hOutputFile);
	bool	WriteNormalsToOutputFile(HANDLE		hOutputFile);

	inline void	SetMaterialIndex	(int		nMaterialIndex)
	{
		m_nMaterialIndex = nMaterialIndex;
	}

	inline void	SetVertexIndices	(WORD		nV1,
									 WORD		nV2,
									 WORD		nV3)
	{
		m_anVertexIndices [0] = nV1;
		m_anVertexIndices [1] = nV2;
		m_anVertexIndices [2] = nV3;
	}

	inline WORD GetVertexIndex		(int		nVertexIndex)
	{
		return m_anVertexIndices [nVertexIndex];
	}

	inline float GetNormal			(int		nNormalIndex)
	{
		return m_afNormal [nNormalIndex];
	}

protected:
//
//			Attributes
//
	int		m_nMaterialIndex;		// Indicator of which Material the face uses
	WORD	m_anVertexIndices[3];	// Indices into the vertex array for the triangle's 3 vertices
	float	m_afNormal[3];			// Face normal vector.
};

#endif // !defined(AFX_FACE_H_INCLUDED_)
////////////////////////////////////////////////////////////////////////////////
