////////////////////////////////////////////////////////////////////////////////
//	Frame.h:	The Jet CFrame class
//
//	This class defines one frame within an animation (kin) file.
//
//	This class is the chunk header for the chunk detail class collection that
//	defines the position and rotation for every bone in one frame of animation for
//	the skeleton defined within the animation file.  There will be one CFrame
//	object for each frame identified in the CKINInfoHeader object's dwFrameCount value
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_FRAME_H_INCLUDED_)
#define AFX_FRAME_H_INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "BaseIMObject.h"
#include "FrameDetail.h"
#include <vector>

typedef std::vector<CFrameDetail *>	FRAMEDETAILVECTOR;

class CFrame : public CBaseIMObject  
{
public:
			CFrame	();
	virtual ~CFrame	();

	DWORD	GetFullSize				();
	DWORD	GetRemainingSize		();
	bool	WriteToOutputFile		(HANDLE			hOutputFile);

	bool CreateNewFrameDetail		(CFrameDetail*&	pCurrentFrameDetail);

	inline void SetFrameNo			(DWORD			dwFrameNo)
	{
		m_theHeader.dwFrameNo = dwFrameNo;
	}

protected:

	typedef struct Header
	{
		char	chChunkID [4];
		DWORD	dwChunkSize;
		DWORD	dwVersion;
		DWORD	dwFrameNo;
	};

	Header				m_theHeader;

	FRAMEDETAILVECTOR	m_vFrameDetails;	// the array of event details for this frame

};

#endif // !defined(AFX_FRAME_H_INCLUDED_)
