////////////////////////////////////////////////////////////////////////////////
//	FrameDetail.cpp:	Implements the Jet CFrameDetail class
//
//	This class defines the position and rotation of one skeleton bone in one
//	aframe within an animation (kin) file.  There will be one CFrameDetail object
//	for each skeleton bone for each frame identified in the CKINInfoHeader
//	object's dwFrameCount value
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "FrameDetail.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

////////////////////////////////////////////////////////////////////////////////
// Construction/Destruction
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//	Default constructor
//
CFrameDetail::CFrameDetail()
{
	m_theData.fPosition[0] = 0.0;
	m_theData.fPosition[1] = 0.0;
	m_theData.fPosition[2] = 0.0;
	m_theData.fRotation[0] = 0.0;
	m_theData.fRotation[1] = 0.0;
	m_theData.fRotation[2] = 0.0;
	m_theData.fRotation[3] = 0.0;
}

////////////////////////////////////////////////////////////////////////////////
//	Standard destructor
//
CFrameDetail::~CFrameDetail()
{
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the full size of this CFrameDetail object in the final .KIN file
//
//   COMMENTS:
//
//	This method will return the length of the full CFrameDetail object
//
//    RETURN VALUES:
//		The full size of this object in the .KIN file
//
DWORD CFrameDetail::GetFullSize()
{
	return sizeof (m_theData);
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the reamining size of this CFrameDetail object after its chunk size
//
//   COMMENTS:
//
//	This class does not containa chunk header, so this routine returns the same
//	value as GtFullSize.
//
//    RETURN VALUES:
//		The remaining size of this object after the chunk size
//
DWORD CFrameDetail::GetRemainingSize()
{
	return GetFullSize ();
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Write this header and its contents to the output file
//
//   COMMENTS:
//
//	This method will write the contents of the CFrameDetail class to the output
//	*.KIN Animation file.
//
//	  hOutputFile		The handle of the output file to use
//
//    RETURN VALUES:
//		true:	If no errors occur
//		false:	Otherwise
//
bool CFrameDetail::WriteToOutputFile(HANDLE			hOutputFile)
{
	if (! PerformTheWrite(hOutputFile, &m_theData, sizeof (m_theData), 
						  "Write of CFrameDetail object failed"))
	{
		return false;
	}
	return true;
}
