////////////////////////////////////////////////////////////////////////////////
//	IMHeader.h:	The Jet IM File Header class
//
//	This class defines the IM File Header, which is the root class for everything
//	else in the file.  Specifically, the File Header contains the INFO Header
//	which in turns contains all the meshes, the influence chunk, etc.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	Note that the length in this case is the length of the entire file, not just
//	the length of the header.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_IMHEADER_H_INCLUDED_)
#define AFX_IMHEADER_H_INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "InfoHeader.h"
#include "BaseIMObject.h"
#include "Mesh.h"
#include <vector>

//typedef std::vector<CTexture *> TEXTUREVECTOR;
//typedef std::vector<CMesh *>    MESHVECTOR;

class CIMHeader : public CBaseIMObject
{
public:
				CIMHeader			();
	virtual		~CIMHeader			();

	void		SetMainInfoHdrAddr	(CInfoHeader * pInfoHeader);
	DWORD		GetFullSize			();
	DWORD		GetRemainingSize	();
	bool		WriteToOutputFile	(HANDLE			hOutputFile);

	inline void SetInfluenceObjectAddr		(CInfluence *	pInfluence)
	{
		m_pInfluence = pInfluence;
	}

	inline void SetAttachmentsObjectAddr	(CAttachments *	pAttachments)
	{
		m_pAttachments = pAttachments;
	}


protected:

	typedef struct Header
	{
		char	chJetFormatID [4];
		DWORD	dwFileSize;
		char	chIMFormatID  [4];
	};

	Header			m_theHeader;	// The file header data
	CInfoHeader *	m_pInfoHeader;	// The Info header that contains everything else in the file
	CInfluence *	m_pInfluence;	// pointer to the main CInfluence object.
	CAttachments *	m_pAttachments;	// pointer to the main CAttachments object.
};

#endif // !defined(AFX_IMHEADER_H_INCLUDED_)
////////////////////////////////////////////////////////////////////////////////
