////////////////////////////////////////////////////////////////////////////////
//	Influence.h:	The Jet Influence object class
//
//	This class defines the Influence object used to describe the influences
//	between meshes, bones, etc. in an articulated model.
//
//	Auran claims this is an optional chunk for simple models non-articulated
//	models, but in fact Jet will reject the IM file if this chunk is not
//	present, even it is indicates that there are no bones present.
//
//	This initial implementation of this class only serves to complete simple
//	non-articulated models, and may not be sufficient for truly articulated
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_INFLUENCE_H_INCLUDED_)
#define AFX_INFLUENCE_H_INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "BaseIMObject.h"
#include "Bone.h"
#include <vector>

typedef std::vector<CBone *> BONEVECTOR;

class CInfluence : public CBaseIMObject  
{
public:
			CInfluence			();
	virtual	~CInfluence			();

	DWORD	GetFullSize			();
	DWORD	GetRemainingSize	();
	bool	WriteToOutputFile	(HANDLE		hOutputFile);
	bool	CreateNewBone		(CBone*&	pCurrentBone);

protected:

	typedef struct Header
	{
		char	chInfluenceChunkID [4];
		DWORD	dwChunkSize;
		DWORD	dwVersion;
		DWORD	dwBoneCount;
	};

	Header	m_theHeader;		// the influence chunk header data
	BONEVECTOR		m_vBone;	// STL Vector of bone objects

};

#endif // !defined(AFX_INFLUENCE_H_INCLUDED_)
////////////////////////////////////////////////////////////////////////////////
