////////////////////////////////////////////////////////////////////////////////
//	InfluenceVertex.cpp:	implementation of the Influence Vertex object class
//
//	This class defines a single influence vertex within a CBoneInfluenceChuck
//	within a CBone object.  It contains a few simple values along with methods
//	to set and write out those values.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "InfluenceVertex.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

////////////////////////////////////////////////////////////////////////////////
// Construction/Destruction
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//	Default constructor
//
CInfluenceVertex::CInfluenceVertex()
{
}

////////////////////////////////////////////////////////////////////////////////
//	Standard destructor
//
CInfluenceVertex::~CInfluenceVertex()
{
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the full size of this object in the final .IM file
//
//   COMMENTS:
//
//	This method will add up the total lengths of all its internal components,
//	and return the total lengths.
//
//    RETURN VALUES:
//		The full size of this object in the .IM file
//
DWORD CInfluenceVertex::GetFullSize ()
{
	return sizeof(m_theValues);
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the reamining size of this  object after its chunk size
//
//   COMMENTS:
//
//	This object has no length field within a standard header, so it will simply
//	return the full length for the remaining length
//
//    RETURN VALUES:
//		The remaining size of this object
//
DWORD CInfluenceVertex::GetRemainingSize ()
{
	return GetFullSize ();
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Write this object and its contents to the output file
//
//   COMMENTS:
//
//	This method will write the contents of the influence vertes object to the
//	output *.IM Indexed Mesh file.
//
//	  hOutputFile		The handle of the output file to use
//
//    RETURN VALUES:
//		true:	If no errors occur
//		false:	Otherwise
//
bool CInfluenceVertex::WriteToOutputFile (HANDLE	hOutputFile)
{
//
//			Write out the object
//
	if (! PerformTheWrite(hOutputFile, &m_theValues, sizeof (m_theValues), 
						  "Write of Influence Vertex values failed"))
	{
		return false;
	}

	return true;
}

////////////////////////////////////////////////////////////////////////////////
