////////////////////////////////////////////////////////////////////////////////
//	InfluenceVertex.h:	The Jet Influence Vertex object class
//
//	This class defines a single influence vertex within a CBoneInfluenceChuck
//	within a CBone object.  It contains a few simple values along with methods
//	to set and write out those values.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_INFLUENCEVERTEX_H__INCLUDED_)
#define AFX_INFLUENCEVERTEX_H__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "BaseIMObject.h"

class CInfluenceVertex : public CBaseIMObject  
{
public:

			CInfluenceVertex		();
	virtual ~CInfluenceVertex		();

	DWORD	GetFullSize				();
	DWORD	GetRemainingSize		();
	bool	WriteToOutputFile		(HANDLE	hOutputFile);

	inline void	SetVertexIndex		(DWORD	dwVertexIndex)
	{
		m_theValues.dwVertexIndex = dwVertexIndex;
	}

	inline void	SetVertexWeight		(float	fWeight)
	{
		m_theValues.fWeight = fWeight;
	}

	inline void	SetVertexLocation	(float	x,
									 float	y,
									 float	z)
	{
		m_theValues.fPosition[0] = x;
		m_theValues.fPosition[1] = y;
		m_theValues.fPosition[2] = z;
	}

protected:

	typedef struct Vertex_Values
	{
		DWORD	dwVertexIndex;
		float	fWeight;
		float	fPosition [3];
	};
	Vertex_Values		m_theValues;		// the mesh header values

};

#endif // !defined(AFX_INFLUENCEVERTEX_H__INCLUDED_)
////////////////////////////////////////////////////////////////////////////////
