////////////////////////////////////////////////////////////////////////////////
//	InfoHeader.cpp:	The Jet INFO Header class
//
//	This class defines the INFO Header, which contains all the meshes, the 
//	influence chunk, etc.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	Note that the length in this case is the length of the entire file, not just
//	the length of the header.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "InfoHeader.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

////////////////////////////////////////////////////////////////////////////////
// Construction/Destruction
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//	Default constructor
//
CInfoHeader::CInfoHeader()
{
	strncpy (&m_theHeader.chInfoChunkID[0], "INFO", 4);
	m_theHeader.dwChunkSize			= GetRemainingSize ();
	m_theHeader.dwVersion			= 102;
	m_theHeader.afPosition[0]		= 0.0;
	m_theHeader.afPosition[1]		= 0.0;
	m_theHeader.afPosition[2]		= 0.0;
	m_theHeader.afRotation[0]		= 1.0;
	m_theHeader.afRotation[1]		= 0.0;
	m_theHeader.afRotation[2]		= 0.0;
	m_theHeader.afRotation[3]		= 0.0;
	m_theHeader.dwMaxInflPerVertex	= 0;	// default to not doing Influence yet
	m_theHeader.dwMaxInflPerChunk	= 0;	// default to not doing Influence yet
}

////////////////////////////////////////////////////////////////////////////////
//	Standard destructor
//
CInfoHeader::~CInfoHeader()
{

}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the full size of this INFO object in the final .IM file
//
//   COMMENTS:
//
//	This method will return the length of the full INFO heading..
//
//    RETURN VALUES:
//		The full size of this object in the .IM file
//
DWORD CInfoHeader::GetFullSize()
{
	CMesh *	ptrMesh;
	DWORD	dwTotalSize	= 0;
//
//			Count the mesh objects we will use, and sum their total size.
//
	m_theHeader.dwChunkCount = 0;
	MESHVECTOR::iterator pMesh = m_pvMeshes->begin ();
	while (pMesh != m_pvMeshes->end ())
	{
		ptrMesh = (*pMesh);
		dwTotalSize += ptrMesh->GetFullSize ();
		m_theHeader.dwChunkCount++;
		pMesh++;
	}

	return sizeof (m_theHeader) + dwTotalSize;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the reamining size of this INFO object after its chunk size
//
//   COMMENTS:
//
//	This method will get the total length of this object in the .IM file, and
//	will subtract the leading "INFO" text and chunk size DWORD to return the
//	remaining size of the object.
//
//    RETURN VALUES:
//		The remaining size of this object after the chunk size
//
DWORD CInfoHeader::GetRemainingSize()
{
	return sizeof (m_theHeader) - (4 + sizeof (DWORD));
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Write this header and its contents to the output file
//
//   COMMENTS:
//
//	This method will write the contents of the INFO Header, which happens to be
//	the whole file, to the output *.IM Indexed Mesh file.
//
//	  hOutputFile		The handle of the output file to use
//
//    RETURN VALUES:
//		true:	If no errors occur
//		false:	Otherwise
//
bool CInfoHeader::WriteToOutputFile(HANDLE			hOutputFile)
{
	CMesh *	ptrMesh;
//
//			Write out the INFO header
//
	if (! PerformTheWrite(hOutputFile, &m_theHeader, sizeof (m_theHeader), 
						  "Write of INFO Header failed"))
	{
		return false;
	}
//
//			Write out each mesh object
//
	MESHVECTOR::iterator pMesh = m_pvMeshes->begin ();
	while (pMesh != m_pvMeshes->end ())
	{
		ptrMesh = (*pMesh);
		ptrMesh->WriteToOutputFile (hOutputFile);
		pMesh++;
	}

	return true;
}

////////////////////////////////////////////////////////////////////////////////
