////////////////////////////////////////////////////////////////////////////////
//	InfoHeader.h:	The Jet INFO Header class
//
//	This class defines the INFO Header, which contains all the meshes, the 
//	influence chunk, etc.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	Note that the length in this case is the length of the entire file, not just
//	the length of the header.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_INFOHEADER_H_INCLUDED_)
#define AFX_INFOHEADER_H_INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "BaseIMObject.h"
#include "Mesh.h"
#include "Influence.h"
#include "Attachments.h"
#include <vector>

//typedef std::vector<CTexture *> TEXTUREVECTOR;
typedef std::vector<CMesh *>    MESHVECTOR;

class CInfoHeader : public CBaseIMObject  
{
public:
			CInfoHeader();
	virtual ~CInfoHeader();

	DWORD	GetFullSize				();
	DWORD	GetRemainingSize		();
	bool	WriteToOutputFile		(HANDLE		hOutputFile);

	inline void	SetMainMeshVectorAddr
									(MESHVECTOR *pvMeshes)
	{
		m_pvMeshes = pvMeshes;
	}

	inline void SetPosition			(float	x,
									 float	y,
									 float	z)
	{
		m_theHeader.afPosition[0] = x;
		m_theHeader.afPosition[1] = y;
		m_theHeader.afPosition[2] = z;
	}

	inline void setMaxInflPerVertex	(DWORD		dwMaxInflPerVertex)
	{
		m_theHeader.dwMaxInflPerVertex = dwMaxInflPerVertex;
	}

	inline void setMaxInflPerChunk	(DWORD		dwMaxInflPerChunk)
	{
		m_theHeader.dwMaxInflPerChunk = dwMaxInflPerChunk;
	}

protected:

	typedef struct Header			// the INFO header data
	{
		char	chInfoChunkID [4];
		DWORD	dwChunkSize;
		DWORD	dwVersion;
		float	afPosition[3];
		float	afRotation[4];
		DWORD	dwChunkCount;
		DWORD	dwMaxInflPerVertex;
		DWORD	dwMaxInflPerChunk;
	};

	Header			m_theHeader;

	MESHVECTOR *	m_pvMeshes;		// pointer to the main mesh vector array

};

#endif // !defined(AFX_INFOHEADER_H_INCLUDED_)
////////////////////////////////////////////////////////////////////////////////
