////////////////////////////////////////////////////////////////////////////////
//	KINHeader.h:	The Jet KIN File Header class
//
//	This class defines the KIN File Header, which is the root class for everything
//	else in the file.  Specifically, the File Header contains the INFO Header
//	which in turns contains all the information on bones and their movements, etc.
//
//	Like most of the Jet Objects, it is derived from CBaseINObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	Note that the length in this case is the length of the entire file, not just
//	the length of the header.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_KINHEADER_H_INCLUDED_)
#define AFX_KINHEADER_H_INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "BaseIMObject.h"
#include "KINInfoHeader.h"
#include "Event.h"
#include "Skeleton.h"
#include "Frame.h"
#include "Mesh.h"
#include <vector>

typedef std::vector<CEventDetail *>	EVENTVECTOR;
typedef std::vector<CFrame *>		FRAMEVECTOR;

class CKINHeader : public CBaseIMObject
{
public:
				CKINHeader			();
	virtual		~CKINHeader			();

	DWORD		GetFullSize			();
	DWORD		GetRemainingSize	();
	bool		WriteToOutputFile	(HANDLE			hOutputFile);

	bool CreateNewEventDetail		(CEventDetail*& pCurrentEventDetail);
	bool CreateNewFrame				(CFrame*&		pCurrentFrame);

	inline void	GetKINInfoHeaderChunk	(CKINInfoHeader*& pKINInfoHeader)
	{
		pKINInfoHeader = &m_KINInfoHeader;
	}

	bool CreateRootBone				(CSkeletonBone*&	pRootBone)
	{
		pRootBone = new CSkeletonBone ();
		pRootBone->AssertValid();
		m_theSkeleton.SetRootBone (pRootBone);
		return true;
	}

protected:

	typedef struct Header
	{
		char	chJetFormatID [4];
		DWORD	dwFileSize;
		char	chKINFormatID  [4];
	};

	Header				m_theHeader;		// The file header data
	CKINInfoHeader		m_KINInfoHeader;	// The Info header that contains everything else in the file

	CEvent				m_theEvent;			// the event object.
	CSkeleton			m_theSkeleton;		// The skeleton object.

	EVENTVECTOR			m_vEvents;			// the array of events for this file
	FRAMEVECTOR			m_vFrames;			// the array of frames for this file
};

#endif // !defined(AFX_KINHEADER_H_INCLUDED_)
////////////////////////////////////////////////////////////////////////////////
