////////////////////////////////////////////////////////////////////////////////
//	KINInfoHeader.cpp:	The Jet INFO Header class
//
//	This class defines the INFO Header, which contains all the meshes, the 
//	influence chunk, etc.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	Note that the length in this case is the length of the entire file, not just
//	the length of the header.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "KINInfoHeader.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

////////////////////////////////////////////////////////////////////////////////
// Construction/Destruction
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//	Default constructor
//
CKINInfoHeader::CKINInfoHeader()
{
	strncpy (&m_theHeader.chInfoChunkID[0], "INFO", 4);
	m_theHeader.dwChunkSize			= 0;
	m_theHeader.dwVersion			= 100;
	m_theHeader2.dwFrameCount		= 0;
	m_theHeader2.dwFrameRate		= 0;
	m_theHeader2.fMetricScaleValue	= 0.0;
	m_szfileName[0] = '\0';
	m_theHeader.dwfileNameSize = GetNameSize (m_szfileName);
}

////////////////////////////////////////////////////////////////////////////////
//	Standard destructor
//
CKINInfoHeader::~CKINInfoHeader()
{

}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the full size of this INFO object in the final .IM file
//
//   COMMENTS:
//
//	This method will return the length of the full INFO heading..
//
//    RETURN VALUES:
//		The full size of this object in the .IM file
//
DWORD CKINInfoHeader::GetFullSize()
{
	DWORD	dwTotalSize	= sizeof (m_theHeader);

	m_theHeader.dwfileNameSize = GetNameSize (m_szfileName);
	dwTotalSize += m_theHeader.dwfileNameSize;
	dwTotalSize += sizeof (m_theHeader2);

	return dwTotalSize;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the reamining size of this INFO object after its chunk size
//
//   COMMENTS:
//
//	This method will get the total length of this object in the .IM file, and
//	will subtract the leading "INFO" text and chunk size DWORD to return the
//	remaining size of the object.
//
//    RETURN VALUES:
//		The remaining size of this object after the chunk size
//
DWORD CKINInfoHeader::GetRemainingSize()
{
	m_theHeader.dwChunkSize = GetFullSize () - (4 + sizeof (DWORD));
	return m_theHeader.dwChunkSize;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Write this header and its contents to the output file
//
//   COMMENTS:
//
//	This method will write the contents of the INFO Header, which happens to be
//	the whole file, to the output *.IM Indexed Mesh file.
//
//	  hOutputFile		The handle of the output file to use
//
//    RETURN VALUES:
//		true:	If no errors occur
//		false:	Otherwise
//
bool CKINInfoHeader::WriteToOutputFile(HANDLE			hOutputFile)
{
	char	szOutputFileName [MAX_PATH + 5];
//
//			Load the output variables with the proper values
//
	m_theHeader.dwfileNameSize = GetNameSize (m_szfileName);
	_strnset (szOutputFileName, 0, GetNameSize (m_szfileName));
	strcpy   (szOutputFileName, m_szfileName);
//
//			Write out the initial INFO header data (with its fixed fields)
//
	GetRemainingSize ();
	if (! PerformTheWrite(hOutputFile, &m_theHeader, sizeof (m_theHeader), 
						  "Write of INFO Header failed"))
	{
		return false;
	}
//
//			Write out the name padded to the next DWORD boundary
//
	if (! PerformTheWrite(hOutputFile, &szOutputFileName, GetNameSize (m_szfileName), 
						  "Write of INFO header mesh name failed"))
	{
		return false;
	}
//
//			Write out the second INFO header data
//
	if (! PerformTheWrite(hOutputFile, &m_theHeader2, sizeof (m_theHeader2), 
						  "Write of INFO Header 2 failed"))
	{
		return false;
	}

	return true;
}


////////////////////////////////////////////////////////////////////////////////
