////////////////////////////////////////////////////////////////////////////////
//	KINInfoHeader.h:	The Jet INFO Header class
//
//	This class defines the INFO Header, which contains all the meshes, the 
//	influence chunk, etc.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	Note that the length in this case is the length of the entire file, not just
//	the length of the header.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_KINInfoHeader_H_INCLUDED_)
#define AFX_KINInfoHeader_H_INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "BaseIMObject.h"
#include "Mesh.h"
#include "Influence.h"
#include "Attachments.h"
#include <vector>

class CKINInfoHeader : public CBaseIMObject  
{
public:
			CKINInfoHeader();
	virtual ~CKINInfoHeader();

	DWORD	GetFullSize				();
	DWORD	GetRemainingSize		();

	bool	WriteToOutputFile		(HANDLE			hOutputFile);

	inline DWORD GetFrameCount		()
	{
		return m_theHeader2.dwFrameCount;
	}

	inline SetFileName				(const char *	szFileName)
	{
		strcpy (m_szfileName, szFileName);
	}

	inline SetFrameCount			(const DWORD dwFrameCount)
	{
		m_theHeader2.dwFrameCount = dwFrameCount;
	}

	inline SetFrameRate				(const DWORD dwFrameRate)
	{
		m_theHeader2.dwFrameRate = dwFrameRate;
	}

	inline SetMetricScale			(const float fMetricScale)
	{
		m_theHeader2.fMetricScaleValue = fMetricScale;
	}

protected:

	typedef struct Header1				// the first INFO header data
	{
		char	chInfoChunkID [4];
		DWORD	dwChunkSize;
		DWORD	dwVersion;
		DWORD	dwfileNameSize;
	};

	typedef struct Header2				// the second INFO header data
	{
		DWORD	dwFrameCount;			// number of frames
		DWORD	dwFrameRate;			// frame rate
		float	fMetricScaleValue;		// ??
	};

	Header1		m_theHeader;			// the first part of the header
	char		m_szfileName [1024];	// the name of the related *.IM file 
	Header2		m_theHeader2;			// the second part of the header

};

#endif // !defined(AFX_KINInfoHeader_H_INCLUDED_)
////////////////////////////////////////////////////////////////////////////////
