////////////////////////////////////////////////////////////////////////////////
//	Material.h:	The Jet Material object class
//
//	This class defines the Material object used to describe the material
//	used on a specific mesh.  A mesh can contain one material, but a material
//	can contain multiple textures.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_MATERIAL_H_INCLUDED_)
#define AFX_MATERIAL_H_INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "BaseIMObject.h"
#include "Texture.h"
#include <vector>

typedef std::vector<CTexture *> TEXTUREVECTOR;

class CMaterial : public CBaseIMObject  
{
public:
			CMaterial();
	virtual ~CMaterial();

	bool	FindRelatedTextures			();
	DWORD	GetFullSize					();
	DWORD	GetRemainingSize			();
	bool	WriteToOutputFile			(HANDLE		hOutputFile);
	bool	CreateNewTexture			(CTexture*&	pCurrentTexture);

	inline void SetMaterialName			(char *		szName)
	{
		m_strMaterialName = szName;
	}

	inline void SetDecoratedName		(char *		szName)
	{
		m_strDecoratedName = szName;
	}

	inline void SetImageTexture			(CTexture *	theTexture)
	{
		m_pImageTexture = theTexture;
	}

	inline CTexture * GetImageTexture	()
	{
		return m_pImageTexture;
	}

	inline CString GetMaterialName		()
	{
		return m_strMaterialName;
	}

	inline void	SetTwoSided				(DWORD	dwTwoSided)
	{
		theAfterHeader.dwTwoSided = dwTwoSided;
	}

	inline void	SetOpacity				(float	fOpacity)
	{
		theAfterHeader.fOpacity = fOpacity;
	}

	inline void	SetAmbientRGB			(float	R,
										 float	G,
										 float	B)
	{
		theAfterHeader.afAmbientRGB[0] = R;
		theAfterHeader.afAmbientRGB[1] = G;
		theAfterHeader.afAmbientRGB[2] = B;
	}

	inline void	SetDiffuseRGB			(float	R,
										 float	G,
										 float	B)
	{
		theAfterHeader.afDiffuseRGB[0] = R;
		theAfterHeader.afDiffuseRGB[1] = G;
		theAfterHeader.afDiffuseRGB[2] = B;
	}

	inline void	SetSpecularRGB			(float	R,
										 float	G,
										 float	B)
	{
		theAfterHeader.afSpecularRGB[0] = R;
		theAfterHeader.afSpecularRGB[1] = G;
		theAfterHeader.afSpecularRGB[2] = B;
	}

	inline void	SetEmissiveRGB			(float	R,
										 float	G,
										 float	B)
	{
		theAfterHeader.afEmissiveRGB[0] = R;
		theAfterHeader.afEmissiveRGB[1] = G;
		theAfterHeader.afEmissiveRGB[2] = B;
	}

	inline void	SetShininess			(float	fShininess)
	{
		theAfterHeader.fShininess = fShininess;
	}


protected:
//
//			Attributes
//
	TEXTUREVECTOR	m_vTexture;			// STL Vector of textures for this material
	CTexture *		m_pImageTexture;	// pointer to the main image texture

	CString	m_strMaterialName;			// the material's name
	CString m_strDecoratedName;			// the decorated material name

	typedef struct Header
	{
		char	chMATLChunkID [4];
		DWORD	dwChunkSize;
		DWORD	dwVersion;
		DWORD	dwNameSize;
	};

	Header	m_theHeader;		// the material chunk's header data
	struct afterHeader
	{
		DWORD	dwNumProperties;	// number of additional properties (none at this time)
		DWORD	dwTwoSided;			// two sided flag
		float	fOpacity;			// opacity value 0.0 to 1.0
		float	afAmbientRGB [3];
		float	afDiffuseRGB [3];
		float	afSpecularRGB[3];
		float	afEmissiveRGB[3];
		float	fShininess;
		DWORD	dwTextureCount;
	} theAfterHeader;

};

#endif // !defined(AFX_MATERIAL_H_INCLUDED_)
////////////////////////////////////////////////////////////////////////////////
