////////////////////////////////////////////////////////////////////////////////
//	Skeleton.cpp:	Implements the Jet CSkeleton class
//
//	This class defines and contains the skeleton that resides in an animation (kin) file.
//
//	Unlike most Jet "chunk" objects, this chunk contains one CSkeletonBone object,
//	not a vector of them.  The CSkeletonBone objects are recursive, and each can contain
//	zero, one, or more child CSkeletonBone objects.  Note that most of the routines
//	for the skeleton objects will be recursive.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "Skeleton.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

////////////////////////////////////////////////////////////////////////////////
// Construction/Destruction
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//	Default constructor
//
CSkeleton::CSkeleton()
{
	strncpy (&m_theHeader.chChunkID[0], "SKEL", 4);
	m_theHeader.dwChunkSize	= 0;
	m_theHeader.dwVersion	= 100;
	m_pRootBone				= NULL;
}

////////////////////////////////////////////////////////////////////////////////
//	Standard destructor
//
CSkeleton::~CSkeleton()
{
	if (m_pRootBone != NULL)
		delete m_pRootBone;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the full size of this CSkeleton object in the final .KIN file
//
//   COMMENTS:
//
//	This method will return the length of the full CSkeleton heading..
//
//    RETURN VALUES:
//		The full size of this object in the .KIN file
//
DWORD CSkeleton::GetFullSize()
{
	DWORD	dwTotalSize	= sizeof (m_theHeader);	// start with the header size

	if (m_pRootBone != NULL)
		dwTotalSize += m_pRootBone->GetFullSize();

	return dwTotalSize;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the reamining size of this INFO object after its chunk size
//
//   COMMENTS:
//
//	This method will get the total length of this object in the .KIN file, and
//	will subtract the leading "SKEL" text and chunk size DWORD to return the
//	remaining size of the object.
//
//    RETURN VALUES:
//		The remaining size of this object after the chunk size
//
DWORD CSkeleton::GetRemainingSize()
{
	m_theHeader.dwChunkSize = GetFullSize () - (4 + sizeof (DWORD));
	return m_theHeader.dwChunkSize;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Write this header and its contents to the output file
//
//   COMMENTS:
//
//	This method will write the contents of the INFO Header, which happens to be
//	the whole file, to the output *.KIN Animation file.
//
//	  hOutputFile		The handle of the output file to use
//
//    RETURN VALUES:
//		true:	If no errors occur
//		false:	Otherwise
//
bool CSkeleton::WriteToOutputFile(HANDLE	hOutputFile)
{
//
//			Write out the CEvent header
//
	GetRemainingSize();
	if (! PerformTheWrite(hOutputFile, &m_theHeader, sizeof (m_theHeader), 
						  "Write of CSkeleton Header failed"))
	{
		return false;
	}
//
//			Write out the individual skeleton objects
//
	if (m_pRootBone != NULL)
		if (! m_pRootBone->WriteToOutputFile(hOutputFile))
		{
			return false;
		}

	return true;
}
