////////////////////////////////////////////////////////////////////////////////
//	Skeleton.h:	The Jet CSkeleton class
//
//	This class defines and contains the skeleton that resides in an animation (kin) file.
//
//	Unlike most Jet "chunk" objects, this chunk contains one CSkeletonBone object,
//	not a vector of them.  The CSkeletonBone objects are recursive, and each can contain
//	zero, one, or more child CSkeletonBone objects.  Note that most of the routines
//	for the skeleton objects will be recursive.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_SKELETON_H_INCLUDED_)
#define AFX_SKELETON_H_INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "BaseIMObject.h"
#include "SkeletonBone.h"

class CSkeleton : public CBaseIMObject  
{
public:
			CSkeleton			();
	virtual ~CSkeleton			();

	DWORD	GetFullSize			();
	DWORD	GetRemainingSize	();
	bool	WriteToOutputFile	(HANDLE				hOutputFile);

	inline void SetRootBone		(CSkeletonBone *	pRootBone)
	{
		m_pRootBone = pRootBone;
	}

protected:

	typedef struct Header
	{
		char	chChunkID [4];
		DWORD	dwChunkSize;
		DWORD	dwVersion;
	};

	Header			m_theHeader;

	CSkeletonBone *	m_pRootBone;

};

#endif // !defined(AFX_SKELETON_H_INCLUDED_)
////////////////////////////////////////////////////////////////////////////////
