////////////////////////////////////////////////////////////////////////////////
//	SkeletonBone.h:	The Jet CSkeletonBone class
//
//	This class defines the recursive SkeletonBone that resides in an animation (kin) file.
//
//	Unlike most Jet "chunk" objects, this chunk is both a data storage object, and a
//	recursive container for zero, one, or more additional CSkeletonBone objects.
//	Note that most of the routines in this object will be recursive.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_SKELETONBONE_H_INCLUDED_)
#define AFX_SKELETONBONE_H_INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "BaseIMObject.h"
#include <vector>

class CSkeletonBone : public CBaseIMObject  
{
public:

typedef std::vector<CSkeletonBone *>	BONEVECTOR;

			CSkeletonBone	();
	virtual ~CSkeletonBone	();

	DWORD	GetFullSize				();
	DWORD	GetRemainingSize		();
	bool	WriteToOutputFile		(HANDLE				hOutputFile);

	bool CreateNewSkeletonBone		(CSkeletonBone*&	pCurrentSkeletonBone);

	inline SetBoneName				(const char *		szBoneName)
	{
		strcpy (m_szName, szBoneName);
	}


protected:

	typedef struct Header
	{
		char	chChunkID [4];
		DWORD	dwChunkSize;
		DWORD	dwVersion;
		DWORD	dwNameSize;
	};

	Header	m_theHeader;
	DWORD	m_dwChildBoneCount;
	char	m_szName [1024];				// the name of the related bone 

	BONEVECTOR		m_vChildBones;			// the array of child bones for this bone

};

#endif // !defined(AFX_SKELETONBONE_H_INCLUDED_)
////////////////////////////////////////////////////////////////////////////////
