////////////////////////////////////////////////////////////////////////////////
//	Texture.cpp:	The Jet Texture object class
//
//	This class implements the Material object used to describe the material
//	used on a specific mesh.  A mesh can contain one material, but a material
//	can contain multiple textures.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "Texture.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

////////////////////////////////////////////////////////////////////////////////
// Construction/Destruction
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//	Default constructor
//
CTexture::CTexture()
{
}

////////////////////////////////////////////////////////////////////////////////
//	Standard destructor
//
CTexture::~CTexture()
{
}


////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Get the full size of this Texture object in the final .IM file
//
//   COMMENTS:
//
//	This method will add up the total lengths of all its internal components,
//	and return the total lengths.
//
//    RETURN VALUES:
//		The full size of this object in the .IM file
//
DWORD CTexture::GetFullSize()
{
	DWORD	dwTotalSize	= 0;

	dwTotalSize = sizeof (m_theHeader) +		// header type
				  GetNameSize (m_szImage) +	// texture image file name size
				  sizeof (float);				// texture amount.

	return dwTotalSize;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Write this object and its contents to the output file
//
//   COMMENTS:
//
//	This method will write the contents of the texture object to the output
//	*.IM Indexed Mesh file.
//
//	  hOutputFile		The handle of the output file to use
//
//    RETURN VALUES:
//		true:	If no errors occur
//		false:	Otherwise
//
bool CTexture::WriteToOutputFile (HANDLE hOutputFile)
{
	char	szOutputFileName [MAX_PATH + 5];
//
//			Load the output variables with the proper values
//
	m_theHeader.dwTextureType = (DWORD) m_eType;
	m_theHeader.dwNameSize = GetNameSize (m_szImage);
	_strnset (szOutputFileName, 0, GetNameSize (m_szImage));
	strcpy   (szOutputFileName, m_szImage);
//
//			Write out the TEXTURE header (with its fixed fields)
//
	if (! PerformTheWrite(hOutputFile, &m_theHeader, sizeof (m_theHeader), 
						  "Write of TEXTURE Header failed"))
	{
		return false;
	}
//
//			Write out the name padded to the next DWORD boundary
//
	if (! PerformTheWrite(hOutputFile, &szOutputFileName, GetNameSize (m_szImage), 
						  "Write of TEXTURE image name failed"))
	{
		return false;
	}
//
//			Write out the texture value
//
	if (! PerformTheWrite(hOutputFile, &m_fValue, sizeof (float), 
						  "Write of TEXTURE value failed"))
	{
		return false;
	}

	return true;
}
////////////////////////////////////////////////////////////////////////////////
