////////////////////////////////////////////////////////////////////////////////
//	Texture.h:	The Jet Texture object class
//
//	This class defines the Material object used to describe the material
//	used on a specific mesh.  A mesh can contain one material, but a material
//	can contain multiple textures.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_TEXTURE_H_INCLUDED_)
#define AFX_TEXTURE_H_INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "BaseIMObject.h"
#include "JetDefs.h"

class CTexture : public CBaseIMObject  
{
public:

			CTexture	();
	virtual ~CTexture	();

	DWORD	GetFullSize			();
	bool	WriteToOutputFile	(HANDLE		hOutputFile);

	inline SetTextureName		(const char *		szTextureName)
	{
		strcpy (m_szTextureName, szTextureName);
	}

	inline SetParentName		(const char *		szParentName)
	{
		strcpy (m_szParent, szParentName);
	}

	inline SetType				(txType		eType)
	{
		m_eType = eType;
	}

	inline SetImageName			(const char *		szImageName)
	{
		strcpy (m_szImage, szImageName);
	}

	inline SetValue				(float		fValue)
	{
		m_fValue = fValue;
	}

	inline char * GetTextureName()
	{
		return m_szTextureName;
	}

protected:
//
//			Attributes
//
	char			m_szTextureName [1024];	// texture name
	char			m_szParent		[1024];	// the texture's material name
	txType			m_eType	;				// texture type
	char			m_szImage		[1024];	// the name of the texture's image file
	float			m_fValue;				// "value" of this texture

	typedef struct Header
	{
		DWORD	dwTextureType;
		DWORD	dwNameSize;
	};

	Header	m_theHeader;			// the MESH header data

};
#endif // !defined(AFX_TEXTURE_H_INCLUDED_)
////////////////////////////////////////////////////////////////////////////////
