////////////////////////////////////////////////////////////////////////////////
//	Vertex.cpp:	The Jet Vertex object class
//
//	This class implements the Material object used to describe the material
//	used on a specific mesh.  A mesh can contain one material, but a material
//	can contain multiple textures.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "Vertex.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

////////////////////////////////////////////////////////////////////////////////
// Construction/Destruction
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//	Default constructor
//
CVertex::CVertex()
{
	m_nFaceIndex = 0;
}

////////////////////////////////////////////////////////////////////////////////
//	Standard destructor
//
CVertex::~CVertex()
{

}


////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Write the vertex coordinates to the output file
//
//   COMMENTS:
//
//	This method will write the 3D space XYZ coordinates and the 2D texture
//	coordinates for this vertex to the output file.
//
//	  hOutputFile		The handle of the output file to use
//
//    RETURN VALUES:
//		true:	If no errors occur
//		false:	Otherwise
//
bool CVertex::WriteCoordsToOutputFile (HANDLE	hOutputFile)
{
	if (! PerformTheWrite(hOutputFile, &m_afCoords, sizeof (m_afCoords), 
						  "Write of Vertex Coordinates failed"))
	{
		return false;
	}
	if (! PerformTheWrite(hOutputFile, &m_afTexCoords, sizeof (m_afTexCoords), 
						  "Write of Vertex Coordinates failed"))
	{
		return false;
	}
	return true;
}

////////////////////////////////////////////////////////////////////////////////
//   PURPOSE: Write the vertex normals to the output file
//
//   COMMENTS:
//
//	This method will write the normal values for this vertex to the output file.
//
//	  hOutputFile		The handle of the output file to use
//
//    RETURN VALUES:
//		true:	If no errors occur
//		false:	Otherwise
//
bool CVertex::WriteNormalsToOutputFile(HANDLE hOutputFile)
{
	if (! PerformTheWrite(hOutputFile, &m_afNormals, sizeof (m_afNormals), 
						  "Write of Vertex Normals failed"))
	{
		return false;
	}
	return true;
}

////////////////////////////////////////////////////////////////////////////////
