////////////////////////////////////////////////////////////////////////////////
//	Vertex.h:	The Jet Vertex object class
//
//	This class defines the Material object used to describe the material
//	used on a specific mesh.  A mesh can contain one material, but a material
//	can contain multiple textures.
//
//	Like most of the Jet Objects, it is derived from CBaseIMObject, and implements
//	the virtual Get Size and Write to Output methods of that base class.
//
//	NOTE: This is assumed to be an open-source project, so individual method
//	notes appear before each method in the CPP file rather than here in the
//	.h file.
//
//	Copyright , Jack Emmerichs, 2001.
//
////////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_VERTEX_H_INCLUDED_)
#define AFX_VERTEX_H_INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "BaseIMObject.h"

#define MAX_FACES 64

class CVertex : public CBaseIMObject  
{
public:
			CVertex();
	virtual ~CVertex();
	bool	WriteCoordsToOutputFile		(HANDLE		hOutputFile);
	bool	WriteNormalsToOutputFile	(HANDLE		hOutputFile);

	inline void SetCoordinates			(int		nIndex,
										 float		fValue)
	{
		m_afCoords[nIndex] = fValue;
	}

	inline void SetNormals				(int		nIndex,
										float		fValue)
	{
		m_afNormals[nIndex] = fValue;
	}

	inline void SetTexCoords			(int		nIndex,
										 float		fValue)
	{
		m_afTexCoords[nIndex] = fValue;
	}

	inline void SetFace					(int		nIndex,
										 int		nFaceIndex)
	{
		m_anFaces[nIndex] = nFaceIndex;
	}

	inline void SetFaceIndex			(int		nFaceIndex)
	{
		m_nFaceIndex = nFaceIndex;
	}

	inline float GetCoords				(int		nIndex)
	{
		return m_afCoords [nIndex];
	}

	inline int GetFaceIndex				()
	{
		return m_nFaceIndex;
	}

	inline int GetFace					(int		nIndex)
	{
		return m_anFaces[nIndex];
	}

	inline float GetTexCoords			(int		nIndex)
	{
		return m_afTexCoords[nIndex];
	}

protected:
//
//			Attributes
//
	float	m_afCoords		[3];			// the X, Y, Z coordinates for this vertex
	float	m_afNormals		[3];			// the normal vector for this vertex
	float	m_afTexCoords	[2];			// uv text coordinates for this vertex
	int		m_anFaces		[MAX_FACES];	// faces that use this vertex
	int		m_nFaceIndex;					// general face index value
};

#endif // !defined(AFX_VERTEX_H_INCLUDED_)
////////////////////////////////////////////////////////////////////////////////
